csverve.core package
====================

Submodules
----------

csverve.core.csverve\_input module
----------------------------------

.. automodule:: csverve.core.csverve_input
    :members:
    :undoc-members:
    :show-inheritance:

csverve.core.csverve\_output module
-----------------------------------

.. automodule:: csverve.core.csverve_output
    :members:
    :undoc-members:
    :show-inheritance:

csverve.core.csverve\_output\_data\_frame module
------------------------------------------------

.. automodule:: csverve.core.csverve_output_data_frame
    :members:
    :undoc-members:
    :show-inheritance:

csverve.core.csverve\_output\_file\_stream module
-------------------------------------------------

.. automodule:: csverve.core.csverve_output_file_stream
    :members:
    :undoc-members:
    :show-inheritance:

csverve.core.irregular\_csv\_input module
-----------------------------------------

.. automodule:: csverve.core.irregular_csv_input
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: csverve.core
    :members:
    :undoc-members:
    :show-inheritance:
